require 'colored'
require 'lazy_domain'
require 'mechanize'
require_relative './gimme_poc/contactpage'
require_relative './gimme_poc/poc'
require_relative './gimme_poc/logger'
require_relative './gimme_poc/questions'
require_relative './gimme_poc/save'
require_relative './gimme_poc/version'
require_relative './gimme_poc/web'

# Find the contact
module Gimme
  class << self
    include Web
    include Questions
    include Save
    include ContactPage

    attr_accessor :page, :contact, :contact_links, :url
    attr_reader :status_code

    def start_url_process(url)
      LogMessages.start_url(url)
      case
      when LazyDomain.valid?(url) == false
        LogMessages.invalid_domain(url)
        @status_code = 0
      when subdomain?(url)
        LogMessages.subdomain
        @status_code = 0 if get(url).nil? && get(orig_domain(url)).nil?
      else
        @status_code = 0 if get(url).nil?
      end
    end

    def start_contact_process(url)
      start_contact_links
      attempt = save_available_contacts(url)
      info = attempt.info if attempt && attempt.respond_to?(:info)
      return attempt unless info.nil? || info.empty?
      go_to_contact_page(url)
    end

    ##
    # The main method!
    # Takes array of urls and gets contact info for each if possible.
    # If url is bad, it's converted to nil in 'get' method and skipped over.
    def poc(arr)
      arr = arr.split unless arr.is_a?(Array)
      results = []
      arr.each do |url|
        start_url_process(url)
        next if @status_code == 0
        results << start_contact_process(url)
      end
      results.length == 1 ? results.first : results
    end

    # Convenience method.
    def memory
      Search.all_sites
    end

    # Clears entire collection.
    def reset!
      Search.all_sites = []
    end
  end
end
